.. include:: ../common_links.inc

.. _development_where_to_start:

Getting Involved
----------------

Iris_ is an Open Source project hosted on Github and as such anyone with a
GitHub account may create an `issue`_ on our `Iris GitHub`_ project page for
raising:

* bug reports
* feature requests
* documentation improvements

The `Iris GitHub`_ project has been configured to use templates for each of
the above issue types when creating a `new issue`_ to ensure the appropriate
information is provided.

A `pull request`_ may also be created by anyone who has become a
**contributor** to Iris_.  Permissions to merge pull requests to the
main code base (master) are only given to **core developers** of Iris_, this is
to ensure a measure of control.

To get started we suggest reading recent `issues`_ and `pull requests`_
for Iris.

If you are new to using GitHub we recommend reading the
`GitHub getting started`_

.. note:: For more information on becoming a contributor_ including a link to
          the Contributors Licence Agreement (CLA) see the
          `Governance <https://scitools.org.uk/organisation.html#governance>`_
          section of the `SciTools`_ ogranization web site.


.. _GitHub getting started: https://docs.github.com/en/github/getting-started-with-github
